@@ -1,10 +1,10 @@
-__version__ = "0.3.32"
+__version__ = "0.3.33"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(Not currently on any branch)'
+__git_branch__ = '(detached from v0.3.33)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '49cb50319e9a4730c8cb0d0692070b03de8fa5f8'
+__git_head_hash__ = 'f6884294b7d2078be113a5af19ef65cc1ac71dc3'
 __git_head_subject__ = 'fix tests'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
